#!/usr/bin/env Rscript
library(ggplot2)
library(reshape2)

source('../plot_common.R')

res <- read.csv('aggregate.csv', as.is=TRUE)
res <- transform(res, tree=basename(tree),
                 algorithm=ifelse(algorithm == 'Full', 'Exact', algorithm))

m <- melt(res, measure.vars=c('time'), id.vars=c('leaves', 'algorithm'))
casted <- dcast(m, leaves~algorithm)
casted <- transform(casted, faster=ifelse(abs(PAM - Exact) <= 1e-5, 'equal', ifelse(PAM < Exact, 'PAM', 'Exact')))

p <- ggplot(subset(casted, !is.na(faster)),
            aes(x=leaves, xend=leaves, y=PAM, yend=Exact, color=faster)) +
  geom_segment() +
  ylab('time (s)') +
  scale_color_grey(name='Faster', end=0.6) +
  scale_y_log10(breaks=c(0.1, 10, 1000), labels=expression(10^-1, 10^1, 10^3)) +
  geom_point(data=subset(casted, !is.na(faster)), size=1.2)

ggsave('n-time-complexity.svg', width=plot_width_wide, height=plot_height)
ggsave('n-time-complexity.png', width=10, height=6)

# Plot memory consumption
mb <- 2^20
gb <- 2^30
mem <- read.csv('memory.csv', as.is=TRUE)
mem <- transform(mem, algorithm=ifelse(algorithm == 'Full', 'Exact', algorithm))
m <- melt(mem, measure.vars='top_heap_bytes', id.vars=c('n_leaves', 'algorithm', 'time'))
casted <- dcast(m, n_leaves+algorithm~variable, max, na.rm=TRUE, fill=as.numeric(NA))
p <- ggplot(casted, aes(x=n_leaves, y=top_heap_bytes/mb, color=algorithm, shape=algorithm)) +
  geom_point(size=1.8) +
  scale_color_grey(end=0.4) +
  ylab('Maximum heap size (MB)') +
  xlab('Number of leaves')

ggsave('n-memory-complexity.svg', width=10, height=6)
ggsave('n-memory-complexity.png', width=10, height=6)
